第十三周作业 - 徐涛% - 博客园
Description: 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53

# 徐涛%

##

# 第十三周作业

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 | `<%@ page language=``"java"` `import``=``"java.util.*"` `pageEncoding=``"utf-8"``%>` `<%` `String path = request.getContextPath();` `String basePath = request.getScheme()+``"://"``+request.getServerName()+``":"``+request.getServerPort()+path+``"/"``;` `%>` `<!DOCTYPE HTML PUBLIC` `"-//W3C//DTD HTML 4.01 Transitional//EN"``>` `<html>` `` `<head>` `` `<title>My JSP` `'register.jsp'` `starting page</title>` `` `</head>` `` `` `<body>` `` `<script type=``"text/javascript"``>` `` `function validate(){` `` `if``(registerForm.uname.value==``""``){` `` `alert(``"账号不能为空!"``);` `` `return``;` `` `}` `` `if``(registerForm.upwd.value==``""``){` `` `alert(``"密码不能为空!"``);` `` `return``;` `` `}` `` `registerForm.submit();` `` `}` `` `</script>` `` `<form name=``"registerForm"` `action=``"DoregServlet"` `method=``"post"``>` `` `用户名:<input type=``"text"` `name=``"uname"``><br>` `` `密 码: <input type=``"password"` `name=``"upwd"``> <br>` `` `<input type=``"submit"` `value=``"注册"` `>` `` `<a href=``"denglu.jsp"``>登录</a>` `` `</form>` `` `` `</body>` `</html>` `` `package` `com.servlet;` `import` `java.io.IOException;` `import` `java.io.PrintWriter;` `import` `javax.servlet.ServletException;` `import` `javax.servlet.http.HttpServlet;` `import` `javax.servlet.http.HttpServletRequest;` `import` `javax.servlet.http.HttpServletResponse;` `import` `com.dao.UsersDao;` `public` `class` `servlet3` `extends` `HttpServlet {` `` `public` `servlet3() {` `` `super``();` `` `}` `` `` `public` `void` `destroy() {` `` `super``.destroy();` `// Just puts "destroy" string in log` `` `// Put your code here` `` `}` `` `public` `void` `doGet(HttpServletRequest request, HttpServletResponse response)` `` `throws` `ServletException, IOException {` `` `doPost (request, response);` `` `` `}` `` `` `public` `void` `doPost(HttpServletRequest request, HttpServletResponse response)` `` `throws` `ServletException, IOException {` `` `String uname = request.getParameter(``"uname"``);` `` `String upwd = request.getParameter(``"upwd"``);` `` `UsersDao usersDao =` `new` `UsersDao();` `` `int` `i=usersDao.reg(uname, upwd);` `` `if``(i>``0``){` `` `` `response.setHeader(``"refresh"``,` `"2;url=login.jsp"``);` `` `}``else``{` `` `` `response.setHeader(``"refresh"``,` `"2;url=reg.jsp"``);` `` `}` `` `}` `` `/**` `` `* Initialization of the servlet. <br>` `` `*` `` `* @throws ServletException if an error occurs` `` `*/` `` `public` `void` `init()` `throws` `ServletException {` `` `// Put your code here` `` `}` `}` `` `` `package` `com.sf.servlet;` `import` `java.io.IOException;` `import` `java.io.PrintWriter;` `import` `javax.servlet.ServletException;` `import` `javax.servlet.http.HttpServlet;` `import` `javax.servlet.http.HttpServletRequest;` `import` `javax.servlet.http.HttpServletResponse;` `import` `com.sf.dao.MsgDao;` `import` `com.sf.dao.UsersDao;` `public` `class` `Doregservlet` `extends` `HttpServlet {` `` `/**` `` `* Constructor of the object.` `` `*/` `` `public` `Doregservlet() {` `` `super``();` `` `}` `` `/**` `` `* Destruction of the servlet. <br>` `` `*/` `` `public` `void` `destroy() {` `` `super``.destroy();` `// Just puts "destroy" string in log` `` `// Put your code here` `` `}` `` `public` `void` `doGet(HttpServletRequest request, HttpServletResponse response)` `` `throws` `ServletException, IOException {` `` `response.setContentType(``"text/html"``);` `` `PrintWriter out = response.getWriter();` `` `request.setCharacterEncoding(``"utf-8"``);` `` `String uname = request.getParameter(``"uname"``);` `` `String upwd = request.getParameter(``"upwd"``);` `` `UsersDao ud =` `new` `UsersDao();` `` `MsgDao md =` `new` `MsgDao();` `` `if` `(ud.register(uname, upwd) >` `0``) {` `` `request.getSession().setAttribute(``"uname"``, uname);` `` `request.getRequestDispatcher(``"denglu.jsp"``).forward(request,` `` `response);` `` `}` `else` `{` `` `out.print(``"注册失败，请重新注册......."``);` `` `response.setHeader(``"refresh"``,` `"3;url=reg.jsp"``);` `` `}` `` `}` `` `public` `void` `doPost(HttpServletRequest request, HttpServletResponse response)` `` `throws` `ServletException, IOException {` `` `doGet(request,response);` `` `}` `` `/**` `` `* Initialization of the servlet. <br>` `` `*` `` `* @throws ServletException if an error occurs` `` `*/` `` `public` `void` `init()` `throws` `ServletException {` `` `// Put your code here` `` `}` `}` `` `` `package` `com.servlet;` `import` `java.io.IOException;` `import` `java.io.PrintWriter;` `import` `javax.servlet.ServletException;` `import` `javax.servlet.http.HttpServlet;` `import` `javax.servlet.http.HttpServletRequest;` `import` `javax.servlet.http.HttpServletResponse;` `import` `com.dao.MsgDao;` `public` `class` `servlet5` `extends` `HttpServlet {` `` `public` `servlet5() {` `` `super``();` `` `}` `` `public` `void` `destroy() {` `` `super``.destroy();` `// Just puts "destroy" string in log` `` `// Put your code here` `` `}` `` `` `public` `void` `doGet(HttpServletRequest request, HttpServletResponse response)` `` `throws` `ServletException, IOException {` `` `doPost(request, response);` `` `}` `` `` `public` `void` `doPost(HttpServletRequest request, HttpServletResponse response)` `` `throws` `ServletException, IOException {` `` `request.setCharacterEncoding(``"utf-8"``);` `` `` `int` `id=Integer.parseInt(request.getParameter(``"id"``));` `` `MsgDao md=``new` `MsgDao();` `` `md.delMail(id);` `` `response.getWriter().print(``"刪除成功....."``);` `` `response.setHeader(``"refresh"``,` `"2;url=main.jsp"``);` `` `response.sendRedirect(``"main2.jsp"``);` `` `}` `` `` `public` `void` `init()` `throws` `ServletException {` `` `` `}` `}` `` `` `` `package` `com.sf.servlet;` `import` `java.io.IOException;` `import` `java.io.PrintWriter;` `import` `javax.servlet.ServletException;` `import` `javax.servlet.http.HttpServlet;` `import` `javax.servlet.http.HttpServletRequest;` `import` `javax.servlet.http.HttpServletResponse;` `import` `com.sf.dao.MsgDao;` `import` `com.sf.entity.Msg;` `public` `class` `Dowriteservlet` `extends` `HttpServlet {` `` `/**` `` `* Constructor of the object.` `` `*/` `` `public` `Dowriteservlet() {` `` `super``();` `` `}` `` `/**` `` `* Destruction of the servlet. <br>` `` `*/` `` `public` `void` `destroy() {` `` `super``.destroy();` `// Just puts "destroy" string in log` `` `// Put your code here` `` `}` `` `public` `void` `doGet(HttpServletRequest request, HttpServletResponse response)` `` `throws` `ServletException, IOException {` `` `response.setContentType(``"text/html"``);` `` `PrintWriter out = response.getWriter();` `` `request.setCharacterEncoding(``"utf-8"``);` `` `String uname = (String) request.getSession().getAttribute(``"uname"``);` `` `String sendto = request.getParameter(``"receiver"``);` `` `String title = request.getParameter(``"title"``);` `` `String content = request.getParameter(``"content"``);` `` `Msg m =` `new` `Msg();` `` `m.setMsgcontent(content);` `` `m.setUsername(uname);` `` `m.setSendto(sendto);` `` `m.setTitle(title);` `` `MsgDao md =` `new` `MsgDao();` `` `md.addMsg(m);` `` `out.print(``"发送成功....."``);` `` `response.setHeader(``"refresh"``,` `"3;url=main.jsp"``);` `` `}` `` `public` `void` `doPost(HttpServletRequest request, HttpServletResponse response)` `` `throws` `ServletException, IOException {` `` `doGet(request,response); }` `` `/**` `` `* Initialization of the servlet. <br>` `` `*` `` `* @throws ServletException if an error occurs` `` `*/` `` `public` `void` `init()` `throws` `ServletException {` `` `}` `}`

posted @ 2022-05-29 20:20 徐涛% 阅读(70) 评论(0) 编辑 收藏 举报